@@ -1,6 +1,4 @@
-import string
-
-class Connectory():
+class Connectory:
     """Base class for connector objects"""
 
     def __init__(self, connector_name):
