@@ -1,6 +1,4 @@
-import string
-
-class ConnectoryFactory():
+class ConnectoryFactory:
     """Factory to build connectors linking models"""
 
     def __init__(self, connector_factory_name, source_type):
