@@ -1,5 +1,5 @@
-from parallelsdk.pllai_routing_toolbox import routing_problem
-from parallelsdk.pllai_scheduling_toolbox import scheduling_problem, scheduling_connector_factory
+from parallelsdk.routing_toolbox import routing_problem
+from parallelsdk.scheduling_toolbox import scheduling_problem, scheduling_connector_factory
 
 
 def get_connector_factory(model_type):
