@@ -23,33 +23,36 @@ def createVRPModel(vrp):
     depot_loc = np.random.uniform(0.0, 10.0, size=(2,))
     vrp.AddDepot(depot_loc)
     delivery_loc = []
-    for k in range(10):
+    for k in range(9):
         delivery = np.random.uniform(0.0, 10.0, size=(2,))
         delivery_loc.append(delivery)
         vrp.AddLocation(position=delivery, demand=random.randint(5, 10))
 
     # vrp.AddVehicle( name="vehicle_%d" %(1), load=0.0, capacity=300)
     for k in range(3):
-        vrp.AddVehicle(name="vehicle_%d" % k, load=0.0, capacity=5)
+        vrp.AddVehicle(name="vehicle_%d" % k, load=0.0, capacity=15)
     vrp.InferDistanceMatrix()
     return vrp
 
 
 def createMappedVRPModel(vrp):
-    vrp.AddDepot("145 Concord Rd Wayland, MA 01778")
-    vrp.AddLocation("13 Lincoln Rd Wayland, MA 01778", demand=random.randint(5, 10), location_id=1)
-    vrp.AddLocation("662 Boston Post Rd, Weston, MA 02493", demand=random.randint(5, 10), location_id=2)
-    vrp.AddLocation("2345 Commonwealth Avenue, Newton, MA 02466", demand=random.randint(5, 10), location_id=3)
-    vrp.AddLocation("180 Hemenway Rd, Framingham, MA 01701", demand=random.randint(5, 10), location_id=4)
-    vrp.AddLocation("72 Wayside Inn Rd, Sudbury, MA 01776", demand=random.randint(5, 10), location_id=5)
-    vrp.AddLocation("22 Flutie Pass, Framingham, MA 01701", demand=random.randint(5, 10), location_id=6)
-    vrp.AddLocation("208 S Great Rd, Lincoln, MA 01773", demand=random.randint(5, 10), location_id=7)
-    vrp.AddLocation("9 Hope Ave, Waltham, MA 02453", demand=random.randint(5, 10), location_id=8)
+    # vrp.AddDepot("145 Concord Rd Wayland, MA 01778")
+    depot_loc = np.random.uniform(0.0, 10.0, size=(2,))
+    depot_loc[0] = 42.35813
+    depot_loc[1] = -71.06288
+    vrp.AddDepot(depot_loc)
+    # Use random integer for demand: random.randint(5, 10)
+    vrp.AddLocation("13 Lincoln Rd Wayland, MA 01778", demand=0, location_id=0)
+    vrp.AddLocation("662 Boston Post Rd, Weston, MA 02493", demand=0, location_id=1)
+    vrp.AddLocation("2345 Commonwealth Avenue, Newton, MA 02466", demand=0, location_id=2)
+    vrp.AddLocation("180 Hemenway Rd, Framingham, MA 01701", demand=0, location_id=3)
+    vrp.AddLocation("72 Wayside Inn Rd, Sudbury, MA 01776", demand=0, location_id=4)
+    vrp.AddLocation("22 Flutie Pass, Framingham, MA 01701", demand=0, location_id=5)
+    vrp.AddLocation("208 S Great Rd, Lincoln, MA 01773", demand=0, location_id=6)
+    vrp.AddLocation("9 Hope Ave, Waltham, MA 02453", demand=0, location_id=7)
     vrp.InferDistanceMatrix(metric='maps', API_key='AIzaSyCGOa79k466MIwCERz5_obRhmONuebj5Cs')
-
     for k in range(3):
-        vrp.AddVehicle(name="vehicle_%d" % k, load=0.0, capacity=30)
-
+        vrp.AddVehicle(name="vehicle_%d" % k, load=0.0, capacity=2147483647) #30
     return vrp
 
 
@@ -221,6 +224,7 @@ def runConnection(optimizer):
     if model == "n":
         pass
     elif model == "r":
+        # vrp = createVRPModel(BuildVRP('example'))
         vrp = createMappedVRPModel(BuildVRP('example'))
         optimizer.run_optimizer_synch(vrp)
         solution = vrp.get_solution()
@@ -246,7 +250,7 @@ def runConnection(optimizer):
     elif model == "j":
         js = BuildJobShopScheduler("job_shop")
         createJobShopModel(js)
-        #createJobShopModelFromData(js.get_instance())
+        # createJobShopModelFromData(js.get_instance())
         optimizer.run_optimizer_synch(js)
         verifyJobShop(js.get_instance())
         js.get_instance().print_solution()
