@@ -1,4 +1,5 @@
-from .proto import optilab_pb2
+import logging
+from parallelsdk.proto import optilab_pb2
 
 
 class ParallelModel:
